CREATE TABLE test (
  id INTEGER PRIMARY KEY AUTOINCREMENT NOT NULL,
  name VARCHAR(100) NULL,
  email VARCHAR(100) NULL,
  createts TIMESTAMP(14) NULL
);
